@@ -1,7 +1,9 @@
 from newsapi import NewsApiClient
 from newsapi.const import categories
-from sourceRank.helper.settings import logger
-from sourceRank.helper.utils import get_best_matching_candidate_from_list, get_nationality_from_country_code
+from sourceRank.helper.settings import logger, default_field
+from sourceRank.helper.utils import (get_best_matching_candidate_from_list,
+                                     get_nationality_from_country_code,
+                                     get_country_name_by_code, parse_url)
 from sourceRank.models.source_credibility_models import NewsAPISourceDoc
 
 
@@ -53,23 +55,39 @@ class NewsAPIConnector(object):
             sources: list = self.get_sources_from_news_api(
                 category=category, country_code=country_code, language=language)
 
+            sources_domains = [parse_url(url=i.get("url")).registered_domain for i in sources]
+
             # Get matching index
             res_source_matching: tuple = get_best_matching_candidate_from_list(
-                candidate=candidate_source, matching_options=sources)
+                candidate=candidate_source, matching_options=sources_domains)
 
             # 2. Retrieve index
-            source_matching_obj: dict = res_source_matching[0]
+            if res_source_matching[1] > 85:
+                source_matching_obj: dict = res_source_matching[0]
 
-            source_matching: NewsAPISourceDoc = NewsAPISourceDoc(
-                id=source_matching_obj.get("id"),
-                name=source_matching_obj.get("name"),
-                description=source_matching_obj.get("description"),
-                url=source_matching_obj.get("url"),
-                category=source_matching_obj.get("category"),
-                language=source_matching_obj.get("language"),
-                country=source_matching_obj.get("country"),
-                nationality=get_nationality_from_country_code(
-                    source_matching_obj.get("country")))
+                source_matching: NewsAPISourceDoc = NewsAPISourceDoc(
+                    id=source_matching_obj.get("id"),
+                    name=source_matching_obj.get("name"),
+                    description=source_matching_obj.get("description"),
+                    url=source_matching_obj.get("url"),
+                    category=source_matching_obj.get("category"),
+                    language=source_matching_obj.get("language"),
+                    country=source_matching_obj.get("country"),
+                    nationality=get_nationality_from_country_code(
+                        source_matching_obj.get("country")),
+                    analysed=True)
+            else:
+                source_matching: NewsAPISourceDoc = NewsAPISourceDoc(
+                    id=default_field,
+                    name=default_field,
+                    description=default_field,
+                    url=candidate_source,
+                    category=default_field,
+                    language=default_field,
+                    country=get_country_name_by_code(country_code=country_code),
+                    nationality=get_nationality_from_country_code(
+                        country_code=country_code),
+                    analysed=False)
 
         except Exception as e:
             logger.error(e)
